@@ -1,26 +1,13 @@
 /*
- * Copyright (C) 2015  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
 #include "grantleeki18nlocalizer.h"
 #include "grantleetheme_debug.h"
 
-#include <QLocale>
 #include <QDebug>
 
 #include <grantlee/safestring.h>
@@ -83,25 +70,25 @@ QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, c
 
 QString GrantleeKi18nLocalizer::localizeContextString(const QString &string, const QString &context, const QVariantList &arguments) const
 {
-    const KLocalizedString str = kxi18nc(qPrintable(context), qPrintable(string));
+    const KLocalizedString str = ki18nc(qPrintable(context), qPrintable(string));
     return processArguments(str, arguments);
 }
 
 QString GrantleeKi18nLocalizer::localizeString(const QString &string, const QVariantList &arguments) const
 {
-    const KLocalizedString str = kxi18n(qPrintable(string));
+    const KLocalizedString str = ki18n(qPrintable(string));
     return processArguments(str, arguments);
 }
 
 QString GrantleeKi18nLocalizer::localizePluralContextString(const QString &string, const QString &pluralForm, const QString &context, const QVariantList &arguments) const
 {
-    const KLocalizedString str = kxi18ncp(qPrintable(context), qPrintable(string), qPrintable(pluralForm));
+    const KLocalizedString str = ki18ncp(qPrintable(context), qPrintable(string), qPrintable(pluralForm));
     return processArguments(str, arguments);
 }
 
 QString GrantleeKi18nLocalizer::localizePluralString(const QString &string, const QString &pluralForm, const QVariantList &arguments) const
 {
-    const KLocalizedString str = kxi18np(qPrintable(string), qPrintable(pluralForm));
+    const KLocalizedString str = ki18np(qPrintable(string), qPrintable(pluralForm));
     return processArguments(str, arguments);
 }
 
